@@ -13,7 +13,7 @@ use Scalar::Util qw(
 );
 use XML::LibXML;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 # default arguments for XML::LibXML
 my $default_libxml_args = {
@@ -279,6 +279,39 @@ sub new
     return $new_X->($self);
 }
 
+# addClass
+#
+# add class using $mod_class
+sub addClass    { $mod_class->('add', @_) }
+
+# append
+#
+# add nodes after last child
+sub append
+{
+    my($X) = shift;
+    my $self = $X->($X);
+
+    my $xml = $self->{_xml} or return $X;
+
+    my $child_nodes = $arg_to_nodes->(@_)
+        or return $X;
+
+    $each->($xml, sub {
+        my $sel = shift or return;
+        # must be able to have children
+        return unless $sel->can('appendChild');
+        # append one or more child nodes
+        $each->($child_nodes, sub {
+            my $node = shift or return;
+            # deep clone child
+            $sel->appendChild( $node->cloneNode(1) );
+        });
+    });
+
+    return $X;
+}
+
 # attr
 #
 # get or set an attribute on selected XML nodes
@@ -342,6 +375,39 @@ sub children
     }
 }
 
+# classes
+#
+# return a list of the classes assigned to elements
+sub classes
+{
+    my($X) = @_;
+    my $self = $X->($X);
+
+    my $xml  = $self->{_xml} or return;
+
+    my $classes;
+
+    # for multiple elements add each element's class attribute
+    # to the list of classes
+    if (reftype $xml eq 'ARRAY') {
+        $classes .= " " . $_->getAttribute('class') for @$xml;
+    }
+    # get class attribute for single element
+    else {
+        $classes = $xml->getAttribute('class');
+    }
+    # build table of unique class names
+    $classes = {
+        map {$_ => 1} grep {defined $_ && $_ =~ /\w+/} split(/\s+/, $classes)
+    };
+
+    return wantarray
+        # return sorted list of classes
+        ? sort keys %$classes
+        # return hashref of classes
+        : $classes;
+}
+
 # each
 #
 # call callback function for each argument
@@ -403,6 +469,22 @@ sub get
         : $nodes;
 }
 
+# hasClass
+#
+# return true (1) / false (0) if any of the elements have
+# the class.  return undef on errors.
+sub hasClass
+{
+    my($X, $class) = @_;
+    # require class name to test
+    return unless defined $class;
+    # get hashref of class names
+    my $classes = $X->classes()
+        or return;
+
+    return $classes->{$class} ? 1 : 0;
+}
+
 # html
 #
 # return html content or if that is not possible return text
@@ -483,75 +565,6 @@ sub last {
         : $new_X->( {_xml => $xml} );
 };
 
-# text
-#
-# return text content
-sub text
-{
-    my($X, $value) = @_;
-    my $self = $X->($X);
-
-    my $xml = $self->{_xml} or return $X;
-
-    if (defined $value) {
-        $each->($xml, sub {
-            my $sel = shift or return;
-            # text replaces everything else so remove child nodes
-            # if they exist
-            $sel->removeChildNodes() if $sel->can('removeChildNodes');
-            # attempt different methods of adding text
-            # XML::LibXML::Element
-            if ($sel->can('appendText')) {
-                $sel->appendText($value);
-            }
-            # XML::LibXML::Text
-            elsif ($sel->can('setData')) {
-                $sel->setData($value);
-            }
-            # XML::LibXML::Node
-            elsif ($sel->can('appendChild')) {
-                $sel->appendChild( $sel->createTextNode($value) );
-            }
-        });
-    }
-    else {
-        my $sel = $first->($xml);
-        return $sel && $sel->can('textContent')
-            ? $sel->textContent
-            : undef;
-    }
-
-    return $X;
-}
-
-# append
-#
-# add nodes after last child
-sub append
-{
-    my($X) = shift;
-    my $self = $X->($X);
-
-    my $xml = $self->{_xml} or return $X;
-
-    my $child_nodes = $arg_to_nodes->(@_)
-        or return $X;
-
-    $each->($xml, sub {
-        my $sel = shift or return;
-        # must be able to have children
-        return unless $sel->can('appendChild');
-        # append one or more child nodes
-        $each->($child_nodes, sub {
-            my $node = shift or return;
-            # deep clone child
-            $sel->appendChild( $node->cloneNode(1) );
-        });
-    });
-
-    return $X;
-}
-
 # prepend
 #
 # add nodes before first child
@@ -603,9 +616,55 @@ sub prepend
     return $X;
 }
 
-# add/remove/toggle class using $mod_class
-sub addClass    { $mod_class->('add', @_) }
+# removeClass
+#
+# remove class using $mod_class
 sub removeClass { $mod_class->('remove', @_) }
+
+# text
+#
+# return text content
+sub text
+{
+    my($X, $value) = @_;
+    my $self = $X->($X);
+
+    my $xml = $self->{_xml} or return $X;
+
+    if (defined $value) {
+        $each->($xml, sub {
+            my $sel = shift or return;
+            # text replaces everything else so remove child nodes
+            # if they exist
+            $sel->removeChildNodes() if $sel->can('removeChildNodes');
+            # attempt different methods of adding text
+            # XML::LibXML::Element
+            if ($sel->can('appendText')) {
+                $sel->appendText($value);
+            }
+            # XML::LibXML::Text
+            elsif ($sel->can('setData')) {
+                $sel->setData($value);
+            }
+            # XML::LibXML::Node
+            elsif ($sel->can('appendChild')) {
+                $sel->appendChild( $sel->createTextNode($value) );
+            }
+        });
+    }
+    else {
+        my $sel = $first->($xml);
+        return $sel && $sel->can('textContent')
+            ? $sel->textContent
+            : undef;
+    }
+
+    return $X;
+}
+
+# toggleClass
+#
+# toggle class using $mod_class
 sub toggleClass { $mod_class->('toggle', @_) }
 
 1;
@@ -618,14 +677,13 @@ HTML::Xit - XML/HTML DOM Manipulation with CSS Selectors
 
 =head1 SYNOPSIS
 
-my $X = new HTML::Xit("http://mysite.com/mydoc.html");
+my $X = HTML::Xit->new("http://mysite.com/mydoc.html");
 
 $X->("a")->each( sub {
     my($X) = @_;
 
     print $X->attr("href");
     print $X->text;
-    print $X->html;
 } );
 
 $X->(".a")->addClass("b c d")->removeClass("c e")->toggleClass("b a");
@@ -650,12 +708,16 @@ DOM manipulation in the style of jQuery using L<XML::LibXML> and L<HTML::Selecto
 
 =item children
 
+=item classes
+
 =item each
 
 =item first
 
 =item get
 
+=item hasClass
+
 =item html
 
 =item last
@@ -677,6 +739,7 @@ L<XML::LibXML>, L<HTML::Selector::XPath>
 =head1 AUTHOR
 
 Ersun Warncke, C<< <ersun.warncke at outlook.com> >>
+
 http://ersun.warnckes.com
 
 =head1 COPYRIGHT
